@@ -1,7 +1,5 @@
 import os
 from pathlib import Path
-from typing import cast
-from xml.etree.ElementTree import Element
 
 import defusedxml.ElementTree as ET
 import schema_salad.ref_resolver
@@ -31,20 +29,14 @@ def test_timeout_stderr_stdout(tmp_path: Path) -> None:
     assert "Test 1 timed out" in stderr
     tree = ET.parse(junit_xml_report)
     try:
-        root = tree.getroot()
-        timeout_text = cast(
-            Element,
-            cast(Element, cast(Element, root.find("testsuite")).find("testcase")).find(
-                "failure"
-            ),
-        ).text
-        timeout_stderr = cast(
-            Element,
-            cast(Element, cast(Element, root.find("testsuite")).find("testcase")).find(
-                "system-err"
-            ),
-        ).text
+        assert (root := tree.getroot()) is not None
+        assert (testsuite_el := root.find("testsuite")) is not None
+        assert (testcase_el := testsuite_el.find("testcase")) is not None
+        assert (failure_el := testcase_el.find("failure")) is not None
+        timeout_text = failure_el.text
         assert timeout_text is not None and "Test timed out" in timeout_text
+        assert (system_err_el := testcase_el.find("system-err")) is not None
+        timeout_stderr = system_err_el.text
         assert timeout_stderr is not None and "timeout stderr" in timeout_stderr
     except AttributeError as e:
         print(junit_xml_report.read_text())
